# MBASIC Ham Radio Programs

Amateur radio utilities and tools

## Available Ham Radio

### Boka-Ei



**Year:** 1980s
**Tags:** 

**[Download boka-ei.bas](boka-ei.bas)**

---

### Qsoedit



**Year:** 1980s
**Tags:** 

**[Download qsoedit.bas](qsoedit.bas)**

---

### Qsofind



**Year:** 1980s
**Tags:** 

**[Download qsofind.bas](qsofind.bas)**

---

### Rbsclock



**Year:** 1980s
**Tags:** 

**[Download rbsclock.bas](rbsclock.bas)**

---

### Rbspurge



**Year:** 1980s
**Tags:** 

**[Download rbspurge.bas](rbspurge.bas)**

---

### Rbsutl31



**Year:** 1980s
**Tags:** 

**[Download rbsutl31.bas](rbsutl31.bas)**

---

### Rsj



**Year:** 1980s
**Tags:** 

**[Download rsj.bas](rsj.bas)**

---

## How to Use

1. **Download** the .bas file you want to use
2. **Open MBASIC** in your preferred UI (Web, Tkinter, Curses, or CLI)
3. **Load the file:**
   - **Web/Tkinter UI:** Click File → Open, select the downloaded file
   - **CLI:** Type `LOAD "filename.bas"`
4. **Run:** Type `RUN` or press the Run button

## About These Ham Radio

These programs are from the CP/M and early PC era (1970s-1980s), 
preserved from historical archives including OAK, Simtel, and CP/M CD-ROMs.
